@@ -15,7 +15,7 @@ def gerar_mensagem_commit():
     repo = Repo(os.getcwd())
 
     # Inclui arquivos staged (adicionados ou modificados)
-    #repo.git.add(all=True)
+    repo.git.add(all=True)
     diff = repo.git.diff("--cached")
 
     if not diff.strip():
@@ -36,6 +36,7 @@ def gerar_mensagem_commit():
     )
 
     response = model.generate_content(
+        model="gemini-2.0-flash",
         contents=[{"role": "user", "parts": [prompt]}]
     )
     return response.text.strip()
